seq = "QCKTSPLSNWHTFLFEYVHLQQSGAELMKPGASVKISCKASGYTFITYWIEWVKQRPGHGLEWIGDILPGSGSTNYNENFKGKATFTADSSSNTAYMQLSSLTSEDSAVYYCARSGYYGNSGFAYWGQGTLVTVSAHVSRTKCVADPAYSMIMDHWIIFVDDMTSELVLEVMVHYVWLRDIVMTQSPSSLTVTAGEKVTMSCKSSQSLLSSGNQKNYLTWYQQIPGQPPKLLIYWASTRESGVPDRFTGSGSGTDFTLTINSVQAEDLAVYYCQNDYTYPLTFGAGTKLELKVYFLEDMSVENQM"
from antpack import PairedChainAnnotator
pc = PairedChainAnnotator()
res = pc.analyze_seq(seq)
import pdb
pdb.set_trace()
